@@ -34,7 +34,12 @@ def get_options_based_on_normalizer(normalizer: Normalizer) -> Iterator[str]:
 
 
 @pytest.mark.parametrize(
-    ("name", "value"), [("installer.parallel", True), ("virtualenvs.create", True)]
+    ("name", "value"),
+    [
+        ("installer.parallel", True),
+        ("virtualenvs.create", True),
+        ("requests.max-retries", 0),
+    ],
 )
 def test_config_get_default_value(config: Config, name: str, value: bool) -> None:
     assert config.get(name) is value
